@@ -807,7 +807,7 @@ static char *GetThreadStr()
 		{
 		unsigned NewThreadStrCount = ThreadIndex + 4;
 		char **NewThreadStrs = myalloc(char *, NewThreadStrCount);
-		zero(NewThreadStrs, NewThreadStrCount);
+		memset_zero(NewThreadStrs, NewThreadStrCount);
 		if (g_ThreadStrCount > 0)
 			memcpy(NewThreadStrs, g_ThreadStrs, g_ThreadStrCount*sizeof(char *));
 		g_ThreadStrs = NewThreadStrs;
@@ -898,6 +898,8 @@ void Log(const char *Format, ...)
 
 void Die_(const char *Format, ...)
 	{
+	va_list ArgList;
+	va_start(ArgList, Format);
 #pragma omp critical
 	{
 	static bool InDie = false;
@@ -908,10 +910,7 @@ void Die_(const char *Format, ...)
 
 	if (g_fLog != 0)
 		setbuf(g_fLog, 0);
-	va_list ArgList;
-	va_start(ArgList, Format);
 	myvstrprintf(Msg, Format, ArgList);
-	va_end(ArgList);
 
 	fprintf(stderr, "\n\n");
 	Log("\n");
@@ -944,6 +943,7 @@ void Die_(const char *Format, ...)
 
 	exit(1);
 	}
+	va_end(ArgList);
 	}
 
 void Warning_(const char *Format, ...)
@@ -2076,7 +2076,8 @@ void GetVersionString(string &s)
 	"T"
 #endif
 	;
-
+	if (GIT_VER == 0)
+		GIT_VER = "-";
 	Ps(s, "%s %s.%s%s [%s]", PROGRAM_NAME, MY_VERSION, GetPlatform(), Flags, GIT_VER);
 	}
 
@@ -2398,15 +2399,8 @@ void LogAllocSummary()
 void *mymalloc64(unsigned BytesPerObject, uint64 N)
 	{
 	uint64 Bytes = N*BytesPerObject;
-	//byte *p = 0;
-	//try
-	//	{
-	//	p = new byte[Bytes];
-	//	}
-	//catch (...)
-	//	{
-	//	Die("myalloc64(%u, %.3g) failed", BytesPerObject, double(N));
-	//	}
+	if (Bytes >= UINT32_MAX - 1024)
+		Die("Memory object >4Gb, probably due to long seqences");
 	byte *p = (byte *) malloc(Bytes);
 	if (p == 0)
 		Die("myalloc64(%u, %.3g) failed", BytesPerObject, double(N));
